@@ -37,10 +37,12 @@ line."
      for dir in .
      do 
        echo processing $dir
-       (cd $dir; \
-       aclocalinclude="$ACLOCAL_FLAGS --acdir=/usr/share/aclocal -I ./m4 -I /usr/local/share/aclocal"; \
-       aclocal $aclocalinclude; \
-       autoheader; automake --add-missing; autoconf)
+       cd $dir
+#       aclocalinclude="$ACLOCAL_FLAGS --acdir=/usr/share/aclocal -I ./m4 -I /usr/local/share/aclocal"; 
+       aclocal $aclocalinclude;
+       autoheader; 
+       automake --add-missing; 
+       autoconf
      done
      ./configure "$@"
 
